@@ -58,7 +58,7 @@ plt.show()
 
 """
 
-__version__ = "4.0.5"
+__version__ = "4.1.0"
 __author__ = "Paul Brodersen"
 __email__ = "paulbrodersen+netgraph@gmail.com"
 
@@ -87,6 +87,11 @@ from ._edge_layout import (
     get_bundled_edge_paths,
 )
 
+from ._interactive_variants import (
+    MutableGraph,
+    EditableGraph,
+)
+
 from ._parser import parse_graph
 
 
@@ -106,5 +111,7 @@ __all__ = ['draw',
            'Basegraph',
            'Graph',
            'InteractiveGraph',
+           'MutableGraph',
+           'EditableGraph',
            'parse_graph',
 ]
