@@ -15,7 +15,7 @@ from rpack import pack
 from itertools import combinations
 
 from grandalf.graphs import Vertex, Edge, Graph
-from grandalf.layouts import SugiyamaLayout
+from grandalf.layouts import SugiyamaLayout, DummyVertex
 
 from ._utils import (
     _edge_list_to_adjacency_matrix,
@@ -25,6 +25,7 @@ from ._utils import (
     _get_n_points_on_a_circle,
     _get_subgraph,
     _invert_dict,
+    _get_connected_components,
 )
 
 
@@ -63,58 +64,6 @@ def _handle_multiple_components(layout_function):
     return wrapped_layout_function
 
 
-def _get_connected_components(adjacency_list):
-    """
-    Get the connected components given a graph in adjacency list format.
-
-    Arguments:
-    ----------
-    adjacency_list : dict node ID : set of node IDs
-        Adjacency list, i.e. a mapping from each node to its neighbours.
-
-    Returns:
-    --------
-    components : list of sets of node IDs
-        The unconnected components of the graph.
-
-    """
-
-    components = []
-    not_visited = set(list(adjacency_list.keys()))
-    while not_visited: # i.e. while stack is non-empty (empty set is interpreted as `False`)
-        start = not_visited.pop()
-        component = _dfs(adjacency_list, start)
-        components.append(component)
-
-        #  remove nodes that are in the component that we just found
-        for node in component:
-            try:
-                not_visited.remove(node)
-            except KeyError:
-                # KeyErrors occur when we try to remove
-                # 1) the start node (which we already popped), or
-                # 2) leaf nodes, i.e. nodes with no outgoing edges
-                pass
-
-    # Often, we are only interested in the largest component,
-    # hence we return the list of components sorted by size, largest first.
-    components = sorted(components, key=len, reverse=True)
-
-    return components
-
-
-def _dfs(adjacency_list, start, visited=None):
-    if visited is None:
-        visited = set()
-    visited.add(start)
-    for node in adjacency_list[start] - visited:
-        if node in adjacency_list:
-            _dfs(adjacency_list, node, visited)
-        else: # otherwise no outgoing edge
-            visited.add(node)
-    return visited
-
-
 def get_layout_for_multiple_components(edges, components, layout_function,
                                        origin = (0, 0),
                                        scale  = (1, 1),
@@ -308,6 +257,8 @@ def get_fruchterman_reingold_layout(edges,
 
     """
 
+    assert len(edges) > 0, "The list of edges has to be non-empty."
+
     # This is just a wrapper around `_fruchterman_reingold`, which implements (the loop body of) the algorithm proper.
     # This wrapper handles the initialization of variables to their defaults (if not explicitely provided),
     # and checks inputs for self-consistency.
@@ -588,7 +539,12 @@ def get_sugiyama_layout(edges, origin=(0,0), scale=(1,1), node_size=3, total_ite
     node_positions = dict()
     for layer in layout.layers:
         for vertex in layer:
-            node_positions[vertex.data] = vertex.view.xy
+            if not isinstance(vertex, DummyVertex):
+                # The DummyVertex class is used by the sugiyama layout to represent
+                # *long* edges, i.e. edges that span over several ranks.
+                # For these edges, a DummyVertex is inserted in every inner layer.
+                # Here we ignore them, as they are not part of the final layout.
+                node_positions[vertex.data] = vertex.view.xy
 
     # rescale to canvas
     # TODO: by rescaling, we effectively ignore the node_size argument
@@ -661,15 +617,26 @@ def get_circular_layout(edges, origin=(0,0), scale=(1,1), reduce_edge_crossings=
     positions = _get_n_points_on_a_circle(center, radius, len(nodes), start_angle=0)
 
     if reduce_edge_crossings:
-        # only optimize if the graph is not complete
-        for edge in combinations(nodes, 2):
-            if (edge not in edges) and (edge[::-1] not in edges):
-                nodes = _reduce_crossings(edges)
-                break
+        if not _is_complete(edges):
+            nodes = _reduce_crossings(edges)
 
     return dict(zip(nodes, positions))
 
 
+def _is_complete(edges):
+    nodes = _get_unique_nodes(edges)
+    minimal_complete_graph = list(combinations(nodes, 2))
+
+    if len(edges) < len(minimal_complete_graph):
+        return False
+
+    for edge in minimal_complete_graph:
+        if (edge not in edges) and (edge[::-1] not in edges):
+            return False
+
+    return True
+
+
 def _reduce_crossings(edges):
     """
     Implements Bauer & Brandes (2005) Crossing reduction in circular layouts.
@@ -862,6 +829,17 @@ def get_community_layout(edges, node_to_community, origin=(0,0), scale=(1,1)):
 
     """
 
+    # assert that there multiple communities in the graph; otherwise abort
+    nodes = _get_unique_nodes(edges)
+    communities = set([node_to_community[node] for node in nodes])
+    if len(communities) < 2:
+        warnings.warn("Graph contains a single community. Unable to compute a community layout. Computing spring layout instead.")
+        return get_fruchterman_reingold_layout(edges, origin=origin, scale=scale)
+
+    # assert that node_to_community is non-redundant,
+    # i.e. only contains nodes that are also present in edges
+    node_to_community = {node : node_to_community[node] for node in nodes}
+
     community_size = _get_community_sizes(node_to_community, scale)
     community_centroids = _get_community_positions(edges, node_to_community, community_size, origin, scale)
     relative_node_positions = _get_node_positions(edges, node_to_community)
